"berrmat" <-
function(obs,Nprop,
                   prior=NULL,Nprior=NULL,
                   nsim=5000,k=length(Nprop),noninf=1/k,
                   beta.noninf=1) {
  if(k!=dim(obs)[1] | k!=dim(obs)[2])
    stop("Length of proportions must match dimension of observations")

  if(dim(obs)[1]!=dim(obs)[2]) stop("Matrix of observations must be square")
                                        #now check the names:
  name.check <- all.equal(dimnames(obs)[[1]],dimnames(obs)[[2]])
  if(is.character(name.check)) stop("rownames must be the same as column names")
  if(!name.check)
    stop("rownames must be the same as column names")

  if(is.null(prior)) {
    ## ie we have not specified a prior,
    ## so we use some sort of non-informative one
    aa <- matrix(0,nsim,k*k)
    for(i in 1:k) {
      startcol <- (i-1)*k + 1
      stopcol <- i*k
      aa[,startcol:stopcol] <- rdirichlet(nsim, obs[i,]+noninf)*Nprop[i]
    }
      dimnames(aa) <- list(NULL,paste(rep(dimnames(obs)[[1]],rep(k,k)),
                                  rep(dimnames(obs)[[1]],k),sep=""))
      aa <- list(   obs = obs,
                Nprop=Nprop,
                prior=noninf,
                nsim=nsim,
                k=k,
                result = aa)

    class(aa) <- "berrmatrix"
    return(aa)
  }


  if(dim(prior)[1]<2) stop("prior matrix is too small (<2), this makes no sense")
  if(dim(prior)[1]!=dim(prior)[2]) stop("prior matrix must be square")
  if(!identical(dimnames(prior)[[1]],dimnames(prior)[[2]]))
    stop("rownames of prior matrix must be the same as column names")

  #maybe it has no dimnames at all, in which case we
  #assume that the obs and prior are in the right order
  if(is.null(dimnames(obs)) & is.null(dimnames(prior))) {
    dimnames(obs)[[1]] <- dimnames(obs)[[2]] <- LETTERS[1:k]
    dimnames(prior)[[1]] <- dimnames(prior)[[2]] <- LETTERS[1:dim(prior)[1]]
  }
    
                                        #and work out the order...
  cat.match <- match(dimnames(prior)[[1]],dimnames(obs)[[1]])
  if(length(cat.match)==0) stop("names in observed matrix don't match prior matrix")
  cat.unmatch <- (1:k)[-cat.match]

                                        #and we rearrange the matrices
                                        #to make subsetting a bit clearer later on.
  obs <- obs[c(cat.match,cat.unmatch),c(cat.match,cat.unmatch)]
  Nprop <- Nprop[c(cat.match,cat.unmatch)]
  
  pk <- k-dim(prior)[1]
  if(pk==0) {
    aa <- .C("berrmat",
             as.double(t(obs)),
             as.double(Nprop),
             as.integer(dim(obs)[1]),
             as.double(t(prior)),
             as.double(Nprior),
             as.integer(nsim),
             as.double(noninf),
             out=double(nsim*(dim(obs)[1]*dim(obs)[1])),PACKAGE="berrmat")$out
    aa <- matrix(aa,nsim,byrow=TRUE)
  }
  else {
    #so the size of the prior doesn't match
    #the size of the observations:
    if(dim(prior)[1] > dim(obs)[1])
      stop("only working with underspecified priors just now")
    km <- length(cat.match)
    kum <- length(cat.unmatch)
    #somewhere to stor all the results...
    bb <- matrix(0,nsim,k*k)
    #and we do the partial matrix:
    obspartial <- obs[1:km,1:km]
    Nproppartial <- Nprop[1:km]/sum(Nprop[1:km])
    aa <- .C("berrmat",
             as.double(t(obspartial)),
             as.double(Nproppartial),
             as.integer(km),
             as.double(t(prior)),
             as.double(Nprior),
             as.integer(nsim),
             as.double(noninf),
             out=double(nsim*km*km),PACKAGE="berrmat")$out
    aa <- matrix(aa,nsim,byrow=TRUE)
    #and do the rest:
    indices <- matrix(1:(k*k),k,k,byrow=TRUE)
    subindices <- matrix(1:(km*km),km,km,byrow=TRUE)
     for(i in 1:km) {
      pmatched <- rbeta(nsim,
                        sum(obs[i,1:km])+beta.noninf,
                        sum(obs[i,(km+1):k])+beta.noninf)
      bb[,indices[i,1:km]] <- (aa[,subindices[i,]]/Nproppartial[i])*pmatched
      bb[,indices[i,(km+1):k]] <- (1-pmatched)*rdirichlet(nsim,obs[i,(km+1):k]+noninf)
      #and the whole row gets balanced by nprop
      bb[,indices[i,]] <- bb[,indices[i,]]*Nprop[i]
    }
    #and any remaining rows...
    for(i in (km+1):k) {
      bb[,indices[i,]] <- rdirichlet(nsim, obs[i,]+noninf)*Nprop[i]
    }
    aa <- bb
  }
  dimnames(aa) <- list(NULL,paste(rep(dimnames(obs)[[1]],rep(k,k)),
                                  rep(dimnames(obs)[[1]],k),sep=""))
  #now we make a list so we can include the original information so it
  #doesn't get lost:
  aa <- list(   obs = obs,
                Nprop=Nprop,
                prior=prior,
                nsim=nsim,
                k=k,
                result = aa)

  class(aa) <- "berrmatrix"
  return(aa)
}
