"plot.berrmatrix" <-
function(x,main="Error Matrix Summary",cutoff=0.8,
    cutoff.col=trellis.par.get()$superpose.symbol$col[c(1,1,2,3)],cutoff.lty=1,cutoff.lwd=1,
         wts=NULL,alpha=0.05,...) {
  #a boxplot of each of the parameters
  #since this is often what you want
  #to know:
  #if we use weights we might want to flag it in the title
  # (but if you use your own title you might not want it
  # flagged:


  #cutoff should be either single no (applies to all four),
  #or four numbers, one for each class type
  if(length(cutoff)==1) cutoff <- rep(cutoff,4)
  if(main=="Error Matrix Summary" & !is.null(wts))
    main <- "Weighted Error Matrix Summary"
  
  if(require(lattice)==FALSE | require(grid)==FALSE)
    stop("error in package loading---you need grid and lattice")
  us <- users(x,wts=wts,print=FALSE)
  pr <- producers(x,wts=wts,print=FALSE)
  kap <- kappa(x,wts=wts,print=FALSE)
  tot <- total(x,wts=wts,print=FALSE)
  k <- dim(us)[[2]]
  nsim <- dim(us)[[1]]
  things <- data.frame(probability = c(tot,kap,c(pr),c(us)),
                       type= c(rep("Total",nsim),
                         rep("Kappa",nsim),
                         rep(paste("prod.'s",dimnames(pr)[[2]]),rep(nsim,k)),
                         rep(paste("users",dimnames(us)[[2]]),rep(nsim,k))),
                       type2=as.factor(c(rep("overall",nsim*2),
                         rep("producers",nsim*k),rep("users",nsim*k))))
  
  things$type <- factor(things$type,
                        levels= rev(c("Total","Kappa",
                          paste("prod.'s",dimnames(pr)[[2]]),
                          paste("users",dimnames(us)[[2]]))))


  #note that panel.abline cycles through each value of v,
  #but doesn't do the same for each value of col,
  #we fix this up with our version:
  my.panel.vline <- function(v,col,lty=add.line$lty, lwd=add.line$lwd,k,...) {
    add.line <- trellis.par.get("add.line")
    v <- as.numeric(v)
    
    if(length(col)==1 & length(v)>1) {
      col <- rep(col,length(v))
    }
                                        #and same thing for the others...
    if(length(lty)==1 & length(v)>1) {
      lty <- rep(lty,length(v))
    }
     if(length(lwd)==1 & length(v)>1) {
      lwd <- rep(lwd,length(v))
    }
 
    topheight <- 2+2*k + 0.5
    chts <- c(topheight, topheight-1, topheight -2, topheight -2 - k, topheight-2-k-k)
    #increase the topheight a bit:
    chts[1] <- chts[1]+0.25
    #decrease the bottom height a bit:
    chts[5] <- chts[5]-0.5
    for (i in seq(along = v)) {
      grid.lines(x = rep(v[i], 2),y=c(chts[i], chts[i+1]), default.units = "native", 
                 gp = gpar(col = col[i], lty = lty[i], lwd = lwd[i]))
    }
    for( i in chts[2:4]) { 
    grid.lines(y=i,default.units="native",gp = gpar(col="lightgrey"))
}
      
}
                                        #set some lattice parameters
  bwplot(type~probability,groups=type2,data=things,
         main=main,xlab="Accuracy",
         panel=function(x,y,...){
           panel.bwsuperpose(x,y,alpha=alpha,...)
           my.panel.vline(v=cutoff,col=cutoff.col,lty=cutoff.lty,lwd=cutoff.lwd,k=k,...)
         }
         )
}

