\name{plot.berrmatrix}
\alias{plot.berrmatrix}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{ The plot method for objects of class berrmatrix}
\description{
  Simple boxplot summary of a \code{berrmatrix} object.
}
\usage{
 \method{plot}{berrmatrix}(x,  cutoff = 0.8,
         cutoff.col="black",cutoff.lty=1,
         cutoff.lwd=1,wts=NULL,alpha=0.05,\ldots)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{x}{An object of class \code{berrmatrix} }
  \item{cutoff}{Limits for accuracy levels.  Vertical lines are drawn at
    each of these values.  Set this to NULL if you don't want any
    vertical lines.
  }
  \item{cutoff.col}{A vector of colours, used to set the colour of each
    of the vertical cutoff lines}
  \item{cutoff.lty}{A vector of line types, used to set the line type of
    each of the vertical cutoff lines}
  \item{cutoff.lwd}{A vector of line widths, used to set the line width of
    each of the vertical cutoff lines}
  \item{wts}{An optional matrix of weights for the analysis.  Each of
    the accuracy values (total, kappa, user's and producer's accuracies)
    will be adjusted appropriately.}
  \item{alpha}{Each of the boxes plotted represent a 1-alpha/2 interval.}
  \item{\dots}{ Other parameters that might be passed to the plotting function. }
}
\details{
  This function creates a simple graphical summary of the main accuracy
  parameters of an error matrix (total, kappa, user's and producer's
  accuracy) by plotting horizontal boxplots for each of the
  parameters.  Rather than the inter-quartile range usually used in a
  boxplot, each box represents a 1-alpha/2 interval.  Vertical lines can
  be placed on the plot, to indicate cutoff values for the acceptance or
  rejection of a map.  So for example, you might reject a map if the
  probability that the total accuracy < 0.8 is alpha/2 or less.  A plot
  with the total accuracy box completely to the right of the line
  passes, one that intersects the box or lies to the left would not pass.
}
\note{This function can take quite a long time, since it calculates all
  the accuracy measures before plotting them.  Also note that since you
  have the posterior for each of the parameters, you don't need to rely
  on this sort of hypothesis testing.
  }
\author{ Robert Denham  }

\seealso{ \code{\link{berrmat}}, \code{\link{total}} }
\examples{

baffle <- matrix(c(5,0,2,0,1,41,1,0,0,1,4,0,0,0,0,5),4,4)
baffle.p <- c(0.05034146,0.84161955,0.07216152,0.03587746)
dimnames(baffle)[[1]] <- dimnames(baffle)[[2]] <-
    c("Class18","Class20",  "Class107", "Class151")
baffle.noninf <- berrmat(baffle,baffle.p)
plot(baffle.noninf, cutoff=0.9,alpha=0.1)
#if the map needs to be at least 90\% accurate then there might be
#a rule something like: P(total accuracy > 0.9) must be > 90\%
#since the box intersects the line, then this map would fail.

}
\keyword{ hplot }


