\name{summary.berrmatrix}
\alias{summary.berrmatrix}

\title{ Print a summary of the accuracy of an error matrix }
\description{
  Simple summary statistics for the error matrix based on the posterior
  distribution of the misclassification proportions.
}
\usage{
\method{summary}{berrmatrix}(x,wts=NULL, ...)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{x}{An object of class \code{berrmatrix}}
  \item{wts}{An optional weight matrix to allow for partial credit for
    incorrect classifications}
  \item{\dots}{ Other parameters might be passed too. }
}
\details{
  Provide summary of the misclassification error, based on simple
  summaries of the posterior.  The object \code{x} would typically be the result
  of a call to \code{berrmat}.
}
\value{
  Simple summaries are printed.
}
\author{Robert Denham }
\note{ Quite a slow function, since it requires calls to
  \code{users},\code{total}, etc, which each take a bit of time. }

\seealso{\code{\link{total}}, \code{\link{plot.berrmatrix}},\code{\link{berrmat}} }
\examples{

baffle <- matrix(c(5,0,2,0,1,41,1,0,0,1,4,0,0,0,0,5),4,4)
baffle.p <- c(0.05034146,0.84161955,0.07216152,0.03587746)
dimnames(baffle)[[1]] <- dimnames(baffle)[[2]] <-
   c("Class18","Class20",  "Class107", "Class151")
baffle.noninf <- berrmat(baffle,baffle.p)
summary(baffle.noninf)

#weighted matrix, example taken from D. G. Rossiter's Technical Note
# available at http://www.itc.nl/personal/rossiter
ross3 <- matrix(c(35,4,12,2,14,11,9,5,11,3,38,12,1,0,4,2),4,4)
dimnames(ross3) <- list(LETTERS[1:4],LETTERS[1:4])
ross3.p <- c(61,18,63,21)/163
ross3.b <- berrmat(ross3,ross3.p,nsim=5000)
ross3.w <- matrix(c(1,0,1,0.91,0,1,0,0,.67,0,1,0.61,1,0,1,1),4,4)
#unweighted summary
summary(ross3.b)

#weighted summary
summary(ross3.b,wts=ross3.w)

}
\keyword{ htest }% at least one, from doc/KEYWORDS

