\name{total}
\alias{users}
\alias{producers}
\alias{total}
\alias{kappa.berrmatrix}
\alias{mean.berrmatrix}
\alias{median.berrmatrix}


\title{Summary statistics for the error matrix}
\description{
  Provide estimates of the common error matrix summaries, user's
  accuracy, producer's accuracy, total accuracy, Cohen's kappa and the
  posterior mean of the misclassification probabilities.
}
\usage{
users(x, wts=NULL,print = TRUE)
producers(x, wts=NULL, print = TRUE)
total(x, wts=NULL, print = TRUE)
\method{kappa}{berrmatrix}(x, print = TRUE)
\method{mean}{berrmatrix}(x, round=TRUE, percent = TRUE, print = TRUE)
median.berrmatrix(x,percent=TRUE, round = 3, print = TRUE, ...)

}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{x}{ A matrix of class \code{berrmatrix}, typically the output of
    \code{berrmat}}
  \item{print}{Boolean value determining whether to print the summary }
  \item{round}{How much rounding when printing the mean values }
  \item{percent}{Convert the proportions to percentages of the posterior
    mean}
  \item{wts}{An optional weight matrix, allowing for partial credit for
    incorrect classifications}
  \item{...}{Other arguments that might be passed.}
}
\details{
  A set of functions that summarise the accuracy of a map based on the
  posterior distribution of the misclassification probabilities.
}
\value{
  A k x k matrix for the mean, which will sum to 100 (or 1 if
  \code{percent=FALSE}).
  A k x k matrix for the mean, which represents the poterior median
  estimate of the misclassification rate, expressed as a percentage (if
  \code{percent=TRUE}) or a proportion otherwise.
  Vectors for \code{total} and \code{kappa}, and matrices with k columns
  for \code{users} and \code{producers}
}

\author{Robert Denham }


\seealso{ \code{\link{berrmat}},\code{\link{plot.berrmatrix}},
  \code{\link{summary.berrmatrix}}}
\examples{

baffle <- matrix(c(5,0,2,0,1,41,1,0,0,1,4,0,0,0,0,5),4,4)
baffle.p <- c(0.05034146,0.84161955,0.07216152,0.03587746)
dimnames(baffle)[[1]] <- dimnames(baffle)[[2]] <-
    c("Class18","Class20",  "Class107", "Class151")
baffle.noninf <- berrmat(baffle,baffle.p)
total(baffle.noninf)

}
\keyword{ htest }% at least one, from doc/KEYWORDS
\keyword{ manip }% __ONLY ONE__ keyword per line
