#include <R.h>
#include <Rmath.h>
#include <Rinternals.h>
#include <stdio.h>


void berrmat(double *obs,  double *Nprop, int *k, 
	    double *pobs, double *Npropprior, 
	    int *nsim, double *noninf, 
	    double *out) {

  int i,j,pos, sim,start;
  int anyzeros = 0;
  double *rowsum,*prowsum;
  double *obstrueprop, *pobstrueprop;
  double *obsstandardised,*pobsadjusted;
  double * pobsadjustedrowtotal;
  double xsum=0.0;

  GetRNGstate();

  /* first get the row and column sums of each */
  /* might have been simpler to do this from R */
  rowsum = (double *) R_alloc(*k, sizeof(double));
  prowsum = (double *) R_alloc(*k, sizeof(double));
  obstrueprop = (double *) R_alloc(*k, sizeof(double));
  pobstrueprop =(double *) R_alloc(*k, sizeof(double));
  obsstandardised = (double *) R_alloc( (*k * *k), sizeof(double));
  pobsadjusted = (double *) R_alloc( (*k * *k), sizeof(double));
  pobsadjustedrowtotal = (double *) R_alloc(*k, sizeof(double));
  
 /* initialise */
  for(i=0;i<*k;i++) {
    rowsum[i]=prowsum[i] = 0.0;
    obstrueprop[i] = pobstrueprop[i] = pobsadjustedrowtotal[i] = 0.0;
  }

  /* and get the sums */
  for(i=0;i< *k; i++) {
    for(j=0;j< *k; j++) {
      pos = i* ((*k)) + j;
      rowsum[i] += obs[pos];
      prowsum[i] += pobs[pos];
    }
  }

  /* and standardise the matrix   */
  /* and get the estimate of the  */
  /* true proportions             */
  
  /* many of these loops could be incorported */
  /* but the time saving would be marginal so */
  /* I haven't bothered */

  for(i=0;i< (*k) ;i++)
    for(j=0;j<(*k);j++) {
      pos = i* ((*k)) + j;
      obsstandardised[pos] = (rowsum[i]>0) ? (obs[pos]/rowsum[i]) * Nprop[i] : 0.0;
      pobs[pos] = (prowsum[i] > 0 ) ? (pobs[pos]/prowsum[i]) * Npropprior[i] : 0.0;
      obstrueprop[j] += obsstandardised[pos];
      pobstrueprop[j] += pobs[pos];
    }

   /* and get the prior to look like the observed */

  for(i=0;i< (*k);i++)
    for(j=0;j<(*k);j++) {
      pos = i* ((*k)) + j;
      pobsadjusted[pos] = pobs[pos] *  (obstrueprop[j]/pobstrueprop[j]);
      pobsadjustedrowtotal[i] += pobsadjusted[pos];
    }


  /* and finally adjust pobs so the row sum is the same as pobs */
   for(i=0;i< (*k);i++)
    for(j=0;j<(*k);j++) {
      pos = i* ((*k)) + j;
      pobsadjusted[pos] = (pobsadjusted[pos] / pobsadjustedrowtotal[i]) * prowsum[i];
      if(pobsadjusted[pos] == 0) anyzeros=1;
    }

  /* if there were any zeros, then we wack on an additional amount */
  /* so we can still sample from the gamma dist.                   */
  if(anyzeros==1) {
    for(i = 0; i < ( (*k) * (*k) ); i++) pobsadjusted[i] += *noninf;
  }
  
  anyzeros = 0;

  /* now we begin the simulation */
  for(sim = 0; sim < (*nsim) ; sim++) {
    /* we do it row by row */
    /* first we reset the true proportions */
    for(j=0;j< (*k); j++) obstrueprop[j] = 0.0;
    
    /* then for each row we sample from dirichlet */
    for(i=0;i< (*k); i++) {
      start = sim * (*k)*(*k) +  i* (*k) ;
      xsum = 0.0;
      for(j=0; j < (*k); j++) {
	pos = i* ((*k)) + j;
	/* only makes sense if Nprop[i] > 0 */
	out[start + j] = (Nprop[i] > 0) ? rgamma(obs[pos]+pobsadjusted[pos],1): 0.0;
	xsum+=out[start + j];
      }
    /* and adjust */
      for(j=0; j < (*k); j++) {
	pos = i* ((*k)) + j;
	out[start + j] = (xsum > 0) ? out[start+j]/xsum * Nprop[i] : 0.0;
	obstrueprop[j] += out[start + j];
      }
      
      /* reset the adjusted row total for this row */
      pobsadjustedrowtotal[i] = 0.0;
    }
    /* that completes one simulation from the error matrix */
    /* now we readjust the prior                           */

    /*let me have a look at the true proportions */
    

    for(i=0;i< (*k);i++) {
      for(j=0;j<(*k);j++) {
	pos = i* ((*k)) + j;
	pobsadjusted[pos] = pobs[pos] *  (obstrueprop[j]/pobstrueprop[j]);
	pobsadjustedrowtotal[i] += pobsadjusted[pos];
      }
    }
    
    /* and finally adjust pobs so the row sum is the same as pobs */
    for(i=0;i< (*k);i++)
      for(j=0;j<(*k);j++) {
	pos = i* ((*k)) + j;
	pobsadjusted[pos] = (pobsadjusted[pos] / pobsadjustedrowtotal[i]) * prowsum[i];
	if(pobsadjusted[pos] == 0) anyzeros=1;
      }


    /* if there were any zeros, then we wack on an additional amount */
    /* so we can still sample from the gamma dist.                   */
    if(anyzeros==1) {
      for(i = 0; i < ( (*k) * (*k) ); i++) pobsadjusted[i] += *noninf;
    }
    
    anyzeros = 0;
    /* and then go to the next simulation */
  }
 PutRNGstate();
 
}

